@@ -89,16 +89,17 @@ class EnglishTest(unittest.TestCase):
         self.assertEqual(locale.format_date(date, full_format=True),
                          'April 28, 2013 at 6:35 pm')
 
-        self.assertEqual(locale.format_date(datetime.datetime.utcnow() - datetime.timedelta(seconds=2), full_format=False),
+        now = datetime.datetime.utcnow()
+
+        self.assertEqual(locale.format_date(now - datetime.timedelta(seconds=2), full_format=False),
                          '2 seconds ago')
-        self.assertEqual(locale.format_date(datetime.datetime.utcnow() - datetime.timedelta(minutes=2), full_format=False),
+        self.assertEqual(locale.format_date(now - datetime.timedelta(minutes=2), full_format=False),
                          '2 minutes ago')
-        self.assertEqual(locale.format_date(datetime.datetime.utcnow() - datetime.timedelta(hours=2), full_format=False),
+        self.assertEqual(locale.format_date(now - datetime.timedelta(hours=2), full_format=False),
                          '2 hours ago')
 
-        now = datetime.datetime.utcnow()
-        self.assertEqual(locale.format_date(now - datetime.timedelta(days=1), full_format=False, shorter=True),
-                         'yesterday')
+        self.assertEqual(locale.format_date(now - datetime.timedelta(days=1),
+                                            full_format=False, shorter=True), 'yesterday')
 
         date = now - datetime.timedelta(days=2)
         self.assertEqual(locale.format_date(date, full_format=False, shorter=True),
